@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2018 Yoran Heling
+  Copyright (c) 2007-2019 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -31,7 +31,7 @@
 #include <time.h>
 
 
-static int graph = 1, show_as = 0, info_show = 0, info_page = 0, info_start = 0, show_items = 0;
+static int graph = 1, show_as = 0, info_show = 0, info_page = 0, info_start = 0, show_items = 0, show_mtime = 0;
 static char *message = NULL;
 
 
@@ -169,22 +169,57 @@ static void browse_draw_graph(struct dir *n, int *x) {
 
 static void browse_draw_items(struct dir *n, int *x) {
   enum ui_coltype c = n->flags & FF_BSEL ? UIC_SEL : UIC_DEFAULT;
+  enum ui_coltype cn = c == UIC_SEL ? UIC_NUM_SEL : UIC_NUM;
 
   if(!show_items)
     return;
   *x += 7;
 
-  if(n->items > 99999) {
-    addstrc(c, "> ");
-    addstrc(c == UIC_SEL ? UIC_NUM_SEL : UIC_NUM, "100");
-    addchc(c, 'k');
-  } else if(n->items) {
-    uic_set(c == UIC_SEL ? UIC_NUM_SEL : UIC_NUM);
+  if(!n->items)
+    return;
+  else if(n->items < 100*1000) {
+    uic_set(cn);
     printw("%6s", fullsize(n->items));
+  } else if(n->items < 1000*1000) {
+    uic_set(cn);
+    printw("%5.1f", n->items / 1000.0);
+    addstrc(c, "k");
+  } else if(n->items < 1000*1000*1000) {
+    uic_set(cn);
+    printw("%5.1f", n->items / 1e6);
+    addstrc(c, "M");
+  } else {
+    addstrc(c, "  > ");
+    addstrc(cn, "1");
+    addchc(c, 'B');
   }
 }
 
 
+static void browse_draw_mtime(struct dir *n, int *x) {
+  enum ui_coltype c = n->flags & FF_BSEL ? UIC_SEL : UIC_DEFAULT;
+  char mbuf[26];
+  struct dir_ext *e;
+  time_t t;
+
+  if (n->flags & FF_EXT) {
+    e = dir_ext_ptr(n);
+  } else if (!strcmp(n->name, "..") && (n->parent->flags & FF_EXT)) {
+    e = dir_ext_ptr(n->parent);
+  } else {
+    snprintf(mbuf, sizeof(mbuf), "no mtime");
+    goto no_mtime;
+  }
+  t = (time_t)e->mtime;
+
+  strftime(mbuf, sizeof(mbuf), "%Y-%m-%d %H:%M:%S %z", localtime(&t));
+  uic_set(c == UIC_SEL ? UIC_NUM_SEL : UIC_NUM);
+no_mtime:
+  printw("%26s", mbuf);
+  *x += 27;
+}
+
+
 static void browse_draw_item(struct dir *n, int row) {
   int x = 0;
 
@@ -207,6 +242,11 @@ static void browse_draw_item(struct dir *n, int row) {
   browse_draw_items(n, &x);
   move(row, x);
 
+  if (extended_info && show_mtime) {
+    browse_draw_mtime(n, &x);
+    move(row, x);
+  }
+
   if(n->flags & FF_DIR)
     c = c == UIC_SEL ? UIC_DIR_SEL : UIC_DIR;
   addchc(c, n->flags & FF_DIR ? '/' : ' ');
@@ -398,6 +438,12 @@ int browse_key(int ch) {
       dirlist_set_sort(DL_COL_ITEMS, dirlist_sort_col == DL_COL_ITEMS ? !dirlist_sort_desc : 1, DL_NOCHANGE);
       info_show = 0;
       break;
+    case 'M':
+      if (extended_info) {
+        dirlist_set_sort(DL_COL_MTIME, dirlist_sort_col == DL_COL_MTIME ? !dirlist_sort_desc : 1, DL_NOCHANGE);
+        info_show = 0;
+      }
+      break;
     case 'e':
       dirlist_set_hidden(!dirlist_hidden);
       info_show = 0;
@@ -463,6 +509,10 @@ int browse_key(int ch) {
     case 'c':
       show_items = !show_items;
       break;
+    case 'm':
+      if (extended_info)
+        show_mtime = !show_mtime;
+      break;
     case 'i':
       info_show = !info_show;
       break;
