@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2018 Yoran Heling
+  Copyright (c) 2007-2019 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -32,7 +32,7 @@
 int page, start;
 
 
-#define KEYS 17
+#define KEYS 19
 char *keys[KEYS*2] = {
 /*|----key----|  |----------------description----------------|*/
         "up, k", "Move cursor up",
@@ -42,11 +42,13 @@ char *keys[KEYS*2] = {
             "n", "Sort by name (ascending/descending)",
             "s", "Sort by size (ascending/descending)",
             "C", "Sort by items (ascending/descending)",
+            "M", "Sort by mtime (-e flag)",
             "d", "Delete selected file or directory",
             "t", "Toggle dirs before files when sorting",
             "g", "Show percentage and/or graph",
             "a", "Toggle between apparent size and disk usage",
             "c", "Toggle display of child item counts",
+            "m", "Toggle display of latest mtime (-e flag)",
             "e", "Show/hide hidden or excluded files",
             "i", "Show information about selected item",
             "r", "Recalculate the current directory",
@@ -97,10 +99,10 @@ void help_draw() {
       ncaddch(10, 4, 'H');
       ncaddch(11, 4, 'e');
       uic_set(UIC_DEFAULT);
-      ncaddstr( 5, 7, "An error occured while reading this directory");
-      ncaddstr( 6, 7, "An error occured while reading a subdirectory");
+      ncaddstr( 5, 7, "An error occurred while reading this directory");
+      ncaddstr( 6, 7, "An error occurred while reading a subdirectory");
       ncaddstr( 7, 7, "File or directory is excluded from the statistics");
-      ncaddstr( 8, 7, "Directory was on an other filesystem");
+      ncaddstr( 8, 7, "Directory was on another filesystem");
       ncaddstr( 9, 7, "This is not a file nor a dir (symlink, socket, ...)");
       ncaddstr(10, 7, "Same file was already counted (hard link)");
       ncaddstr(11, 7, "Empty directory");
