@@ -170,13 +170,13 @@ void addparentstats(struct dir *, int64_t, int64_t, uint64_t, int);
 #define nstack_init(_s) do {\
     (_s)->size = 10;\
     (_s)->top = 0;\
-    (_s)->list = malloc(10*sizeof(*(_s)->list));\
+    (_s)->list = xmalloc(10*sizeof(*(_s)->list));\
   } while(0)
 
 #define nstack_push(_s, _v) do {\
     if((_s)->size <= (_s)->top) {\
       (_s)->size *= 2;\
-      (_s)->list = realloc((_s)->list, (_s)->size*sizeof(*(_s)->list));\
+      (_s)->list = xrealloc((_s)->list, (_s)->size*sizeof(*(_s)->list));\
     }\
     (_s)->list[(_s)->top++] = _v;\
   } while(0)
@@ -186,5 +186,10 @@ void addparentstats(struct dir *, int64_t, int64_t, uint64_t, int);
 #define nstack_free(_s) free((_s)->list)
 
 
+/* Malloc wrappers that exit on OOM */
+void *xmalloc();
+void *xcalloc(size_t, size_t);
+void *xrealloc(void *, size_t);
+
 #endif
 
